@@ -5,7 +5,7 @@ without sending any data to the remote server.
 from mitmproxy import http
 
 
-def request(flow):
+def request(flow: http.HTTPFlow) -> None:
     # pretty_url takes the "Host" header of the request into account, which
     # is useful in transparent mode where we usually only have the IP otherwise.
 
