@@ -7,12 +7,16 @@ from mitmproxy import version
 
 class WSGIApp:
     """
-        An addon that hosts a WSGI app withing mitproxy, at a specified
+        An addon that hosts a WSGI app within mitproxy, at a specified
         hostname and port.
     """
     def __init__(self, app, host, port):
         self.app, self.host, self.port = app, host, port
 
+    @property
+    def name(self):
+        return "wsgiapp:%s:%s" % (self.host, self.port)
+
     def serve(self, app, flow):
         """
             Serves app on flow, and prevents further handling of the flow.
