@@ -41,7 +41,9 @@ def get_header(val, headers):
 
 
 class _HeaderMixin:
-    unique_name = None
+    @property
+    def unique_name(self):
+        return None
 
     def values(self, settings):
         return (
@@ -203,7 +205,7 @@ class Response(_HTTP2Message):
         return ":".join([i.spec() for i in self.tokens])
 
 
-class NestedResponse(base.NestedMessage):
+class NestedResponse(message.NestedMessage):
     preamble = "s"
     nest_type = Response
 
