@@ -1,28 +1,23 @@
 import pytest
 
 from mitmproxy.addons import intercept
-from mitmproxy import options
 from mitmproxy import exceptions
 from mitmproxy.test import taddons
 from mitmproxy.test import tflow
 
 
-class Options(options.Options):
-    def __init__(self, *, intercept=None, **kwargs):
-        self.intercept = intercept
-        super().__init__(**kwargs)
-
-
 def test_simple():
     r = intercept.Intercept()
-    with taddons.context(options=Options()) as tctx:
+    with taddons.context(r) as tctx:
         assert not r.filt
         tctx.configure(r, intercept="~q")
         assert r.filt
+        assert tctx.options.intercept_active
         with pytest.raises(exceptions.OptionsError):
             tctx.configure(r, intercept="~~")
         tctx.configure(r, intercept=None)
         assert not r.filt
+        assert not tctx.options.intercept_active
 
         tctx.configure(r, intercept="~s")
 
@@ -35,6 +30,15 @@ def test_simple():
         assert not f.intercepted
 
         f = tflow.tflow(resp=True)
-        f.reply._state = "handled"
         r.response(f)
         assert f.intercepted
+
+        tctx.configure(r, intercept_active=False)
+        f = tflow.tflow(resp=True)
+        tctx.cycle(r, f)
+        assert not f.intercepted
+
+        tctx.configure(r, intercept_active=True)
+        f = tflow.tflow(resp=True)
+        tctx.cycle(r, f)
+        assert f.intercepted
