@@ -2,7 +2,6 @@ import pytest
 
 from mitmproxy.addons import onboarding
 from mitmproxy.test import taddons
-from mitmproxy import options
 from .. import tservers
 
 
@@ -10,26 +9,32 @@ class TestApp(tservers.HTTPProxyTest):
     def addons(self):
         return [onboarding.Onboarding()]
 
-    def test_basic(self):
-        with taddons.context() as tctx:
-            tctx.configure(self.addons()[0])
+    @pytest.mark.asyncio
+    async def test_basic(self):
+        ob = onboarding.Onboarding()
+        with taddons.context(ob) as tctx:
+            tctx.configure(ob)
             assert self.app("/").status_code == 200
 
     @pytest.mark.parametrize("ext", ["pem", "p12"])
-    def test_cert(self, ext):
-        with taddons.context() as tctx:
-            tctx.configure(self.addons()[0])
+    @pytest.mark.asyncio
+    async def test_cert(self, ext):
+        ob = onboarding.Onboarding()
+        with taddons.context(ob) as tctx:
+            tctx.configure(ob)
             resp = self.app("/cert/%s" % ext)
             assert resp.status_code == 200
             assert resp.content
 
     @pytest.mark.parametrize("ext", ["pem", "p12"])
-    def test_head(self, ext):
-        with taddons.context() as tctx:
-            tctx.configure(self.addons()[0])
+    @pytest.mark.asyncio
+    async def test_head(self, ext):
+        ob = onboarding.Onboarding()
+        with taddons.context(ob) as tctx:
+            tctx.configure(ob)
             p = self.pathoc()
             with p.connect():
-                resp = p.request("head:'http://%s/cert/%s'" % (options.APP_HOST, ext))
+                resp = p.request("head:'http://%s/cert/%s'" % (tctx.options.onboarding_host, ext))
                 assert resp.status_code == 200
                 assert "Content-Length" in resp.headers
                 assert not resp.content
