@@ -1,16 +1,15 @@
 import sys
 import pytest
 from mitmproxy.platform import pf
-from mitmproxy.test import tutils
 
 
 class TestLookup:
 
-    def test_simple(self):
+    def test_simple(self, tdata):
         if sys.platform == "freebsd10":
-            p = tutils.test_data.path("mitmproxy/data/pf02")
+            p = tdata.path("mitmproxy/data/pf02")
         else:
-            p = tutils.test_data.path("mitmproxy/data/pf01")
+            p = tdata.path("mitmproxy/data/pf01")
         with open(p, "rb") as f:
             d = f.read()
 
