@@ -1,37 +1,29 @@
+import asyncio
 import os
 import socket
 import time
-import pytest
 from unittest import mock
 
-from mitmproxy.test import tutils
-from mitmproxy import controller
-from mitmproxy import options
-from mitmproxy.addons import script
-from mitmproxy.addons import proxyauth
-from mitmproxy import http
-from mitmproxy.proxy.config import HostMatcher, parse_server_spec
+import pytest
+
 import mitmproxy.net.http
-from mitmproxy.net import tcp
-from mitmproxy.net import socks
 from mitmproxy import certs
 from mitmproxy import exceptions
+from mitmproxy import http
+from mitmproxy import options
+from mitmproxy.addons import script
+from mitmproxy.net import socks
+from mitmproxy.net import tcp
 from mitmproxy.net.http import http1
-from mitmproxy.net.tcp import Address
+from mitmproxy.proxy.config import HostMatcher
+from mitmproxy.utils import data
 from pathod import pathoc
 from pathod import pathod
-
 from .. import tservers
 from ...conftest import skip_appveyor
 
 
-"""
-    Note that the choice of response code in these tests matters more than you
-    might think. libcurl treats a 304 response code differently from, say, a
-    200 response code - it will correctly terminate a 304 response with no
-    content-length header, whereas it will block forever waiting for content
-    for a 200 response.
-"""
+cdata = data.Data(__name__)
 
 
 class CommonMixin:
@@ -39,48 +31,6 @@ class CommonMixin:
     def test_large(self):
         assert len(self.pathod("200:b@50k").content) == 1024 * 50
 
-    @staticmethod
-    def wait_until_not_live(flow):
-        """
-        Race condition: We don't want to replay the flow while it is still live.
-        """
-        s = time.time()
-        while flow.live:
-            time.sleep(0.001)
-            if time.time() - s > 5:
-                raise RuntimeError("Flow is live for too long.")
-
-    def test_replay(self):
-        assert self.pathod("304").status_code == 304
-        assert len(self.master.state.flows) == 1
-        l = self.master.state.flows[-1]
-        assert l.response.status_code == 304
-        l.request.path = "/p/305"
-        self.wait_until_not_live(l)
-        rt = self.master.replay_request(l, block=True)
-        assert l.response.status_code == 305
-
-        # Disconnect error
-        l.request.path = "/p/305:d0"
-        rt = self.master.replay_request(l, block=True)
-        assert rt
-        if isinstance(self, tservers.HTTPUpstreamProxyTest):
-            assert l.response.status_code == 502
-        else:
-            assert l.error
-
-        # Port error
-        l.request.port = 1
-        # In upstream mode, we get a 502 response from the upstream proxy server.
-        # In upstream mode with ssl, the replay will fail as we cannot establish
-        # SSL with the upstream proxy.
-        rt = self.master.replay_request(l, block=True)
-        assert rt
-        if isinstance(self, tservers.HTTPUpstreamProxyTest):
-            assert l.response.status_code == 502
-        else:
-            assert l.error
-
     def test_http(self):
         f = self.pathod("304")
         assert f.status_code == 304
@@ -120,13 +70,12 @@ class TcpMixin:
 
     def _ignore_on(self):
         assert not hasattr(self, "_ignore_backup")
-        self._ignore_backup = self.config.check_ignore
-        self.config.check_ignore = HostMatcher(
-            [".+:%s" % self.server.port] + self.config.check_ignore.patterns)
+        self._ignore_backup = self.options.ignore_hosts
+        self.options.ignore_hosts = [".+:%s" % self.server.port] + self.options.ignore_hosts
 
     def _ignore_off(self):
         assert hasattr(self, "_ignore_backup")
-        self.config.check_ignore = self._ignore_backup
+        self.options.ignore_hosts = self._ignore_backup
         del self._ignore_backup
 
     def test_ignore(self):
@@ -136,8 +85,6 @@ class TcpMixin:
         i2 = self.pathod("306")
         self._ignore_off()
 
-        self.master.event_queue.join()
-
         assert n.status_code == 304
         assert i.status_code == 305
         assert i2.status_code == 306
@@ -147,9 +94,9 @@ class TcpMixin:
 
         # Test that we get the original SSL cert
         if self.ssl:
-            i_cert = certs.SSLCert(i.sslinfo.certchain[0])
-            i2_cert = certs.SSLCert(i2.sslinfo.certchain[0])
-            n_cert = certs.SSLCert(n.sslinfo.certchain[0])
+            i_cert = certs.Cert(i.sslinfo.certchain[0])
+            i2_cert = certs.Cert(i2.sslinfo.certchain[0])
+            n_cert = certs.Cert(n.sslinfo.certchain[0])
 
             assert i_cert == i2_cert
             assert i_cert != n_cert
@@ -166,13 +113,12 @@ class TcpMixin:
 
     def _tcpproxy_on(self):
         assert not hasattr(self, "_tcpproxy_backup")
-        self._tcpproxy_backup = self.config.check_tcp
-        self.config.check_tcp = HostMatcher(
-            [".+:%s" % self.server.port] + self.config.check_tcp.patterns)
+        self._tcpproxy_backup = self.options.tcp_hosts
+        self.options.tcp_hosts = [".+:%s" % self.server.port] + self.options.tcp_hosts
 
     def _tcpproxy_off(self):
         assert hasattr(self, "_tcpproxy_backup")
-        self.config.check_tcp = self._tcpproxy_backup
+        self.options.tcp_hosts = self._tcpproxy_backup
         del self._tcpproxy_backup
 
     def test_tcp(self):
@@ -182,8 +128,6 @@ class TcpMixin:
         i2 = self.pathod("306")
         self._tcpproxy_off()
 
-        self.master.event_queue.join()
-
         assert n.status_code == 304
         assert i.status_code == 305
         assert i2.status_code == 306
@@ -193,11 +137,12 @@ class TcpMixin:
 
         # Test that we get the original SSL cert
         if self.ssl:
-            i_cert = certs.SSLCert(i.sslinfo.certchain[0])
-            i2_cert = certs.SSLCert(i2.sslinfo.certchain[0])
-            n_cert = certs.SSLCert(n.sslinfo.certchain[0])
+            i_cert = certs.Cert(i.sslinfo.certchain[0])
+            i2_cert = certs.Cert(i2.sslinfo.certchain[0])
+            n_cert = certs.Cert(n.sslinfo.certchain[0])
 
-            assert i_cert == i2_cert == n_cert
+            assert i_cert == i2_cert
+            assert i_cert != n_cert
 
         # Make sure that TCP messages are in the event log.
         # Re-enable and fix this when we start keeping TCPFlows in the state.
@@ -244,24 +189,21 @@ class TestHTTP(tservers.HTTPProxyTest, CommonMixin):
     def test_reconnect(self):
         req = "get:'%s/p/200:b@1:da'" % self.server.urlbase
         p = self.pathoc()
+
         with p.connect():
             assert p.request(req)
             # Server has disconnected. Mitmproxy should detect this, and reconnect.
             assert p.request(req)
             assert p.request(req)
 
-    def test_get_connection_switching(self):
-        def switched(l):
-            for i in l:
-                if "serverdisconnect" in i:
-                    return True
-
+    @pytest.mark.asyncio
+    async def test_get_connection_switching(self):
         req = "get:'%s/p/200:b@1'"
         p = self.pathoc()
         with p.connect():
             assert p.request(req % self.server.urlbase)
             assert p.request(req % self.server2.urlbase)
-        assert switched(self.proxy.tlog)
+        assert await self.proxy.tmaster.await_log("serverdisconnect")
 
     def test_blank_leading_line(self):
         p = self.pathoc()
@@ -275,14 +217,17 @@ class TestHTTP(tservers.HTTPProxyTest, CommonMixin):
             resp = p.request("get:'http://foo':h':foo'='bar'")
         assert resp.status_code == 400
 
-    def test_stream_modify(self):
+    @pytest.mark.asyncio
+    async def test_stream_modify(self, tdata):
         s = script.Script(
-            tutils.test_data.path("mitmproxy/data/addonscripts/stream_modify.py")
+            tdata.path("mitmproxy/data/addonscripts/stream_modify.py"),
+            False,
         )
-        self.master.addons.add(s)
+        self.set_addons(s)
+        await self.master.await_log("stream_modify running")
+
         d = self.pathod('200:b"foo"')
         assert d.content == b"bar"
-        self.master.addons.remove(s)
 
     def test_first_line_rewrite(self):
         """
@@ -300,65 +245,28 @@ class TestHTTP(tservers.HTTPProxyTest, CommonMixin):
             assert self.server.last_log()["request"]["first_line_format"] == "relative"
 
 
-class TestHTTPAuth(tservers.HTTPProxyTest):
-    def test_auth(self):
-        self.master.addons.add(proxyauth.ProxyAuth())
-        self.master.options.auth_singleuser = "test:test"
-        assert self.pathod("202").status_code == 407
-        p = self.pathoc()
-        with p.connect():
-            ret = p.request("""
-                get
-                'http://localhost:%s/p/202'
-                h'%s'='%s'
-            """ % (
-                self.server.port,
-                "Proxy-Authorization",
-                proxyauth.mkauth("test", "test")
-            ))
-        assert ret.status_code == 202
-
-
-class TestHTTPReverseAuth(tservers.ReverseProxyTest):
-    def test_auth(self):
-        self.master.addons.add(proxyauth.ProxyAuth())
-        self.master.options.auth_singleuser = "test:test"
-        assert self.pathod("202").status_code == 401
-        p = self.pathoc()
-        with p.connect():
-            ret = p.request("""
-                get
-                '/p/202'
-                h'%s'='%s'
-            """ % (
-                "Authorization",
-                proxyauth.mkauth("test", "test")
-            ))
-        assert ret.status_code == 202
-
-
 class TestHTTPS(tservers.HTTPProxyTest, CommonMixin, TcpMixin):
     ssl = True
     ssloptions = pathod.SSLOptions(request_client_cert=True)
 
-    def test_clientcert_file(self):
+    def test_clientcert_file(self, tdata):
         try:
-            self.config.clientcerts = os.path.join(
-                tutils.test_data.path("mitmproxy/data/clientcert"), "client.pem")
+            self.options.client_certs = os.path.join(
+                tdata.path("mitmproxy/data/clientcert"), "client.pem")
             f = self.pathod("304")
             assert f.status_code == 304
             assert self.server.last_log()["request"]["clientcert"]["keyinfo"]
         finally:
-            self.config.clientcerts = None
+            self.options.client_certs = None
 
-    def test_clientcert_dir(self):
+    def test_clientcert_dir(self, tdata):
         try:
-            self.config.clientcerts = tutils.test_data.path("mitmproxy/data/clientcert")
+            self.options.client_certs = tdata.path("mitmproxy/data/clientcert")
             f = self.pathod("304")
             assert f.status_code == 304
             assert self.server.last_log()["request"]["clientcert"]["keyinfo"]
         finally:
-            self.config.clientcerts = None
+            self.options.client_certs = None
 
     def test_error_post_connect(self):
         p = self.pathoc()
@@ -392,7 +300,7 @@ class TestHTTPSUpstreamServerVerificationWTrustedCert(tservers.HTTPProxyTest):
     ssloptions = pathod.SSLOptions(
         cn=b"example.mitmproxy.org",
         certs=[
-            ("example.mitmproxy.org", tutils.test_data.path("mitmproxy/data/servercert/trusted-leaf.pem"))
+            ("example.mitmproxy.org", cdata.path("../data/servercert/trusted-leaf.pem"))
         ]
     )
 
@@ -401,21 +309,21 @@ class TestHTTPSUpstreamServerVerificationWTrustedCert(tservers.HTTPProxyTest):
         with p.connect():
             return p.request("get:/p/242")
 
-    def test_verification_w_cadir(self):
-        self.config.options.update(
+    def test_verification_w_confdir(self, tdata):
+        self.options.update(
             ssl_insecure=False,
-            ssl_verify_upstream_trusted_cadir=tutils.test_data.path(
+            ssl_verify_upstream_trusted_confdir=tdata.path(
                 "mitmproxy/data/servercert/"
             ),
             ssl_verify_upstream_trusted_ca=None,
         )
         assert self._request().status_code == 242
 
-    def test_verification_w_pemfile(self):
-        self.config.options.update(
+    def test_verification_w_pemfile(self, tdata):
+        self.options.update(
             ssl_insecure=False,
-            ssl_verify_upstream_trusted_cadir=None,
-            ssl_verify_upstream_trusted_ca=tutils.test_data.path(
+            ssl_verify_upstream_trusted_confdir=None,
+            ssl_verify_upstream_trusted_ca=tdata.path(
                 "mitmproxy/data/servercert/trusted-root.pem"
             ),
         )
@@ -431,7 +339,7 @@ class TestHTTPSUpstreamServerVerificationWBadCert(tservers.HTTPProxyTest):
     ssloptions = pathod.SSLOptions(
         cn=b"example.mitmproxy.org",
         certs=[
-            ("example.mitmproxy.org", tutils.test_data.path("mitmproxy/data/servercert/self-signed.pem"))
+            ("example.mitmproxy.org", cdata.path("../data/servercert/self-signed.pem"))
         ])
 
     def _request(self):
@@ -442,13 +350,13 @@ class TestHTTPSUpstreamServerVerificationWBadCert(tservers.HTTPProxyTest):
     @classmethod
     def get_options(cls):
         opts = super().get_options()
-        opts.ssl_verify_upstream_trusted_ca = tutils.test_data.path(
-            "mitmproxy/data/servercert/trusted-root.pem"
+        opts.ssl_verify_upstream_trusted_ca = cdata.path(
+            "../data/servercert/trusted-root.pem"
         )
         return opts
 
     def test_no_verification_w_bad_cert(self):
-        self.config.options.ssl_insecure = True
+        self.options.ssl_insecure = True
         r = self._request()
         assert r.status_code == 242
 
@@ -456,10 +364,10 @@ class TestHTTPSUpstreamServerVerificationWBadCert(tservers.HTTPProxyTest):
         # We only test for a single invalid cert here.
         # Actual testing of different root-causes (invalid hostname, expired, ...)
         # is done in mitmproxy.net.
-        self.config.options.ssl_insecure = False
+        self.options.ssl_insecure = False
         r = self._request()
         assert r.status_code == 502
-        assert b"Certificate Verification Error" in r.raw_content
+        assert b"Certificate verification error" in r.raw_content
 
 
 class TestHTTPSNoCommonName(tservers.HTTPProxyTest):
@@ -470,7 +378,7 @@ class TestHTTPSNoCommonName(tservers.HTTPProxyTest):
     ssl = True
     ssloptions = pathod.SSLOptions(
         certs=[
-            (b"*", tutils.test_data.path("mitmproxy/data/no_common_name.pem"))
+            ("*", cdata.path("../data/no_common_name.pem"))
         ]
     )
 
@@ -482,6 +390,35 @@ class TestHTTPSNoCommonName(tservers.HTTPProxyTest):
 class TestReverse(tservers.ReverseProxyTest, CommonMixin, TcpMixin):
     reverse = True
 
+    def test_host_header(self):
+        self.options.keep_host_header = True
+        p = self.pathoc()
+        with p.connect():
+            resp = p.request("get:/p/200:h'Host'='example.com'")
+        assert resp.status_code == 200
+
+        req = self.master.state.flows[0].request
+        assert req.host_header == "example.com"
+
+    def test_overridden_host_header(self):
+        self.options.keep_host_header = False  # default value
+        p = self.pathoc()
+        with p.connect():
+            resp = p.request("get:/p/200:h'Host'='example.com'")
+        assert resp.status_code == 200
+
+        req = self.master.state.flows[0].request
+        assert req.host_header == "127.0.0.1"
+
+    @pytest.mark.asyncio
+    async def test_selfconnection(self):
+        self.options.mode = "reverse:http://127.0.0.1:0"
+
+        p = self.pathoc()
+        with p.connect():
+            p.request("get:/")
+        assert await self.master.await_log("The proxy shall not connect to itself.")
+
 
 class TestReverseSSL(tservers.ReverseProxyTest, CommonMixin, TcpMixin):
     reverse = True
@@ -550,7 +487,7 @@ class TestSocks5SSL(tservers.SocksModeTest):
         p = self.pathoc_raw()
         with p.connect():
             p.socks_connect(("localhost", self.server.port))
-            p.convert_to_ssl()
+            p.convert_to_tls()
             f = p.request("get:/p/200")
         assert f.status_code == 200
 
@@ -560,8 +497,6 @@ class TestHttps2Http(tservers.ReverseProxyTest):
     @classmethod
     def get_options(cls):
         opts = super().get_options()
-        s = parse_server_spec(opts.upstream_server)
-        opts.upstream_server = "http://%s" % s.address
         return opts
 
     def pathoc(self, ssl, sni=None):
@@ -582,7 +517,6 @@ class TestHttps2Http(tservers.ReverseProxyTest):
         p = self.pathoc(ssl=True, sni="example.com")
         with p.connect():
             assert p.request("get:'/p/200'").status_code == 200
-            assert all("Error in handle_sni" not in msg for msg in self.proxy.tlog)
 
     def test_http(self):
         p = self.pathoc(ssl=False)
@@ -593,16 +527,16 @@ class TestHttps2Http(tservers.ReverseProxyTest):
 class TestTransparent(tservers.TransparentProxyTest, CommonMixin, TcpMixin):
     ssl = False
 
-    def test_tcp_stream_modify(self):
+    def test_tcp_stream_modify(self, tdata):
         s = script.Script(
-            tutils.test_data.path("mitmproxy/data/addonscripts/tcp_stream_modify.py")
+            tdata.path("mitmproxy/data/addonscripts/tcp_stream_modify.py"),
+            False,
         )
-        self.master.addons.add(s)
+        self.set_addons(s)
         self._tcpproxy_on()
         d = self.pathod('200:b"foo"')
         self._tcpproxy_off()
         assert d.content == b"bar"
-        self.master.addons.remove(s)
 
 
 class TestTransparentSSL(tservers.TransparentProxyTest, CommonMixin, TcpMixin):
@@ -682,7 +616,7 @@ class TestProxy(tservers.HTTPProxyTest):
         first_flow = self.master.state.flows[0]
         second_flow = self.master.state.flows[1]
         assert first_flow.server_conn.timestamp_tcp_setup
-        assert first_flow.server_conn.timestamp_ssl_setup is None
+        assert first_flow.server_conn.timestamp_tls_setup is None
         assert second_flow.server_conn.timestamp_tcp_setup
         assert first_flow.server_conn.timestamp_tcp_setup == second_flow.server_conn.timestamp_tcp_setup
 
@@ -696,12 +630,13 @@ class TestProxy(tservers.HTTPProxyTest):
 class TestProxySSL(tservers.HTTPProxyTest):
     ssl = True
 
-    def test_request_ssl_setup_timestamp_presence(self):
+    def test_request_tls_attribute_presence(self):
         # tests that the ssl timestamp is present when ssl is used
         f = self.pathod("304:b@10k")
         assert f.status_code == 304
         first_flow = self.master.state.flows[0]
-        assert first_flow.server_conn.timestamp_ssl_setup
+        assert first_flow.server_conn.timestamp_tls_setup
+        assert first_flow.client_conn.tls_extensions
 
     def test_via(self):
         # tests that the ssl timestamp is present when ssl is used
@@ -711,32 +646,27 @@ class TestProxySSL(tservers.HTTPProxyTest):
         assert not first_flow.server_conn.via
 
 
-class MasterRedirectRequest(tservers.TestMaster):
-    redirect_port = None  # Set by TestRedirectRequest
+class ARedirectRequest:
+    def __init__(self, redirect_port):
+        self.redirect_port = redirect_port
 
-    @controller.handler
     def request(self, f):
         if f.request.path == "/p/201":
-
             # This part should have no impact, but it should also not cause any exceptions.
             addr = f.live.server_conn.address
-            addr2 = Address(("127.0.0.1", self.redirect_port))
+            addr2 = ("127.0.0.1", self.redirect_port)
             f.live.set_server(addr2)
             f.live.set_server(addr)
 
             # This is the actual redirection.
             f.request.port = self.redirect_port
-        super().request(f)
 
-    @controller.handler
     def response(self, f):
-        f.response.content = bytes(f.client_conn.address.port)
-        f.response.headers["server-conn-id"] = str(f.server_conn.source_address.port)
-        super().response(f)
+        f.response.content = bytes(f.client_conn.address[1])
+        f.response.headers["server-conn-id"] = str(f.server_conn.source_address[1])
 
 
 class TestRedirectRequest(tservers.HTTPProxyTest):
-    masterclass = MasterRedirectRequest
     ssl = True
 
     def test_redirect(self):
@@ -749,7 +679,7 @@ class TestRedirectRequest(tservers.HTTPProxyTest):
 
         This test verifies that the original destination is restored for the third request.
         """
-        self.master.redirect_port = self.server2.port
+        self.set_addons(ARedirectRequest(self.server2.port))
 
         p = self.pathoc()
         with p.connect():
@@ -758,13 +688,13 @@ class TestRedirectRequest(tservers.HTTPProxyTest):
             r1 = p.request("get:'/p/200'")
             assert r1.status_code == 200
             assert self.server.last_log()
-            assert not self.server2.last_log()
+            assert not self.server2.expect_log(1, 0.5)
 
             self.server.clear_log()
             self.server2.clear_log()
             r2 = p.request("get:'/p/201'")
             assert r2.status_code == 201
-            assert not self.server.last_log()
+            assert not self.server.expect_log(1, 0.5)
             assert self.server2.last_log()
 
             self.server.clear_log()
@@ -772,25 +702,23 @@ class TestRedirectRequest(tservers.HTTPProxyTest):
             r3 = p.request("get:'/p/202'")
             assert r3.status_code == 202
             assert self.server.last_log()
-            assert not self.server2.last_log()
+            assert not self.server2.expect_log(1, 0.5)
 
             assert r1.content == r2.content == r3.content
 
 
-class MasterStreamRequest(tservers.TestMaster):
+class AStreamRequest:
 
     """
         Enables the stream flag on the flow for all requests
     """
-    @controller.handler
     def responseheaders(self, f):
         f.response.stream = True
 
 
 class TestStreamRequest(tservers.HTTPProxyTest):
-    masterclass = MasterStreamRequest
-
     def test_stream_simple(self):
+        self.set_addons(AStreamRequest())
         p = self.pathoc()
         with p.connect():
             # a request with 100k of data but without content-length
@@ -799,6 +727,7 @@ class TestStreamRequest(tservers.HTTPProxyTest):
             assert len(r1.content) > 100000
 
     def test_stream_multiple(self):
+        self.set_addons(AStreamRequest())
         p = self.pathoc()
         with p.connect():
             # simple request with streaming turned on
@@ -810,6 +739,7 @@ class TestStreamRequest(tservers.HTTPProxyTest):
             assert r1.status_code == 201
 
     def test_stream_chunked(self):
+        self.set_addons(AStreamRequest())
         connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         connection.connect(("127.0.0.1", self.proxy.port))
         fconn = connection.makefile("rb")
@@ -830,65 +760,60 @@ class TestStreamRequest(tservers.HTTPProxyTest):
         connection.close()
 
 
-class MasterFakeResponse(tservers.TestMaster):
-    @controller.handler
+class AFakeResponse:
     def request(self, f):
         f.response = http.HTTPResponse.wrap(mitmproxy.test.tutils.tresp())
 
 
 class TestFakeResponse(tservers.HTTPProxyTest):
-    masterclass = MasterFakeResponse
 
     def test_fake(self):
+        self.set_addons(AFakeResponse())
         f = self.pathod("200")
         assert "header-response" in f.headers
 
 
 class TestServerConnect(tservers.HTTPProxyTest):
-    masterclass = MasterFakeResponse
     ssl = True
 
     @classmethod
     def get_options(cls):
         opts = tservers.HTTPProxyTest.get_options()
-        opts.no_upstream_cert = True
+        opts.upstream_cert = False
         return opts
 
-    def test_unnecessary_serverconnect(self):
-        """A replayed/fake response with no_upstream_cert should not connect to an upstream server"""
+    @pytest.mark.asyncio
+    async def test_unnecessary_serverconnect(self):
+        """A replayed/fake response with no upstream_cert should not connect to an upstream server"""
+        self.set_addons(AFakeResponse())
         assert self.pathod("200").status_code == 200
-        for msg in self.proxy.tmaster.tlog:
-            assert "serverconnect" not in msg
+        await asyncio.sleep(0.1)
+        assert not self.proxy.tmaster.has_log("serverconnect")
 
 
-class MasterKillRequest(tservers.TestMaster):
+class AKillRequest:
 
-    @controller.handler
     def request(self, f):
         f.reply.kill()
 
 
 class TestKillRequest(tservers.HTTPProxyTest):
-    masterclass = MasterKillRequest
-
     def test_kill(self):
+        self.set_addons(AKillRequest())
         with pytest.raises(exceptions.HttpReadDisconnect):
             self.pathod("200")
         # Nothing should have hit the server
-        assert not self.server.last_log()
+        assert not self.server.expect_log(1, 0.5)
 
 
-class MasterKillResponse(tservers.TestMaster):
-
-    @controller.handler
+class AKillResponse:
     def response(self, f):
         f.reply.kill()
 
 
 class TestKillResponse(tservers.HTTPProxyTest):
-    masterclass = MasterKillResponse
-
     def test_kill(self):
+        self.set_addons(AKillResponse())
         with pytest.raises(exceptions.HttpReadDisconnect):
             self.pathod("200")
         # The server should have seen a request
@@ -902,9 +827,7 @@ class TestTransparentResolveError(tservers.TransparentProxyTest):
         assert self.pathod("304").status_code == 502
 
 
-class MasterIncomplete(tservers.TestMaster):
-
-    @controller.handler
+class AIncomplete:
     def request(self, f):
         resp = http.HTTPResponse.wrap(mitmproxy.test.tutils.tresp())
         resp.content = None
@@ -912,9 +835,8 @@ class MasterIncomplete(tservers.TestMaster):
 
 
 class TestIncompleteResponse(tservers.HTTPProxyTest):
-    masterclass = MasterIncomplete
-
     def test_incomplete(self):
+        self.set_addons(AIncomplete())
         assert self.pathod("200").status_code == 502
 
 
@@ -997,7 +919,7 @@ class TestUpstreamProxySSL(
 
     def test_change_upstream_proxy_connect(self):
         # skip chain[0].
-        self.proxy.tmaster.addons.add(
+        self.set_addons(
             UpstreamProxyChanger(
                 ("127.0.0.1", self.chain[1].port)
             )
@@ -1010,6 +932,40 @@ class TestUpstreamProxySSL(
         assert len(self.chain[0].tmaster.state.flows) == 0
         assert len(self.chain[1].tmaster.state.flows) == 1
 
+    def test_connect_https_to_http(self):
+        """
+        https://github.com/mitmproxy/mitmproxy/issues/2329
+
+        Client <- HTTPS -> Proxy <- HTTP -> Proxy <- HTTPS -> Server
+        """
+        self.set_addons(RewriteToHttp())
+        self.chain[1].set_addons(RewriteToHttps())
+        p = self.pathoc()
+        with p.connect():
+            resp = p.request("get:'/p/418'")
+
+        assert self.proxy.tmaster.state.flows[0].client_conn.tls_established
+        assert not self.proxy.tmaster.state.flows[0].server_conn.tls_established
+        assert not self.chain[1].tmaster.state.flows[0].client_conn.tls_established
+        assert self.chain[1].tmaster.state.flows[0].server_conn.tls_established
+        assert resp.status_code == 418
+
+
+class RewriteToHttp:
+    def http_connect(self, f):
+        f.request.scheme = "http"
+
+    def request(self, f):
+        f.request.scheme = "http"
+
+
+class RewriteToHttps:
+    def http_connect(self, f):
+        f.request.scheme = "https"
+
+    def request(self, f):
+        f.request.scheme = "https"
+
 
 class UpstreamProxyChanger:
     def __init__(self, addr):
@@ -1040,8 +996,9 @@ class TestProxyChainingSSLReconnect(tservers.HTTPUpstreamProxyTest):
         proxified to an upstream http proxy, we need to send the CONNECT
         request again.
         """
-        self.chain[0].tmaster.addons.add(RequestKiller([1, 2]))
-        self.chain[1].tmaster.addons.add(RequestKiller([1]))
+
+        self.chain[0].set_addons(RequestKiller([1, 2]))
+        self.chain[1].set_addons(RequestKiller([1]))
 
         p = self.pathoc()
         with p.connect():
@@ -1055,6 +1012,7 @@ class TestProxyChainingSSLReconnect(tservers.HTTPUpstreamProxyTest):
             assert len(self.chain[1].tmaster.state.flows) == 1
 
             req = p.request("get:'/p/418:b\"content2\"'")
+
             assert req.status_code == 502
 
             assert len(self.proxy.tmaster.state.flows) == 2
@@ -1072,18 +1030,18 @@ class TestProxyChainingSSLReconnect(tservers.HTTPUpstreamProxyTest):
 class AddUpstreamCertsToClientChainMixin:
 
     ssl = True
-    servercert = tutils.test_data.path("mitmproxy/data/servercert/trusted-root.pem")
+    servercert = cdata.path("../data/servercert/trusted-root.pem")
     ssloptions = pathod.SSLOptions(
         cn=b"example.mitmproxy.org",
         certs=[
-            (b"example.mitmproxy.org", servercert)
+            ("example.mitmproxy.org", servercert)
         ]
     )
 
     def test_add_upstream_certs_to_client_chain(self):
         with open(self.servercert, "rb") as f:
             d = f.read()
-        upstreamCert = certs.SSLCert.from_pem(d)
+        upstreamCert = certs.Cert.from_pem(d)
         p = self.pathoc()
         with p.connect():
             upstream_cert_found_in_client_chain = False
