@@ -1,94 +1,35 @@
-from threading import Thread, Event
-from unittest.mock import Mock
+import asyncio
 import queue
 import pytest
 
 from mitmproxy.exceptions import Kill, ControlException
 from mitmproxy import controller
-from mitmproxy import master
-from mitmproxy import proxy
+from mitmproxy.test import taddons
+import mitmproxy.ctx
 
 
-class TMsg:
-    pass
+@pytest.mark.asyncio
+async def test_master():
 
+    class tAddon:
+        def log(self, _):
+            ctx.master.should_exit.set()
 
-class TestMaster:
-    def test_simple(self):
-        class DummyMaster(master.Master):
-            @controller.handler
-            def log(self, _):
-                m.should_exit.set()
+    with taddons.context(tAddon()) as ctx:
+        assert not ctx.master.should_exit.is_set()
 
-            def tick(self, timeout):
-                # Speed up test
-                super().tick(0)
+        async def test():
+            mitmproxy.ctx.log("test")
 
-        m = DummyMaster(None, proxy.DummyServer(None))
-        assert not m.should_exit.is_set()
-        msg = TMsg()
-        msg.reply = controller.DummyReply()
-        m.event_queue.put(("log", msg))
-        m.run()
-        assert m.should_exit.is_set()
-
-    def test_server_simple(self):
-        m = master.Master(None, proxy.DummyServer(None))
-        m.start()
-        m.shutdown()
-        m.start()
-        m.shutdown()
-
-
-class TestServerThread:
-    def test_simple(self):
-        m = Mock()
-        t = master.ServerThread(m)
-        t.run()
-        assert m.serve_forever.called
-
-
-class TestChannel:
-    def test_tell(self):
-        q = queue.Queue()
-        channel = controller.Channel(q, Event())
-        m = Mock(name="test_tell")
-        channel.tell("test", m)
-        assert q.get() == ("test", m)
-        assert m.reply
-
-    def test_ask_simple(self):
-        q = queue.Queue()
-
-        def reply():
-            m, obj = q.get()
-            assert m == "test"
-            obj.reply.handle()
-            obj.reply.send(42)
-            obj.reply.take()
-            obj.reply.commit()
-
-        Thread(target=reply).start()
-
-        channel = controller.Channel(q, Event())
-        assert channel.ask("test", Mock(name="test_ask_simple")) == 42
-
-    def test_ask_shutdown(self):
-        q = queue.Queue()
-        done = Event()
-        done.set()
-        channel = controller.Channel(q, done)
-        with pytest.raises(Kill):
-            channel.ask("test", Mock(name="test_ask_shutdown"))
+        asyncio.ensure_future(test())
+        assert await ctx.master.await_log("test")
+        assert ctx.master.should_exit.is_set()
 
 
 class TestReply:
     def test_simple(self):
         reply = controller.Reply(42)
-        assert reply.state == "unhandled"
-
-        reply.handle()
-        assert reply.state == "handled"
+        assert reply.state == "start"
 
         reply.send("foo")
         assert reply.value == "foo"
@@ -104,7 +45,6 @@ class TestReply:
 
     def test_kill(self):
         reply = controller.Reply(43)
-        reply.handle()
         reply.kill()
         reply.take()
         reply.commit()
@@ -112,7 +52,6 @@ class TestReply:
 
     def test_ack(self):
         reply = controller.Reply(44)
-        reply.handle()
         reply.ack()
         reply.take()
         reply.commit()
@@ -120,7 +59,6 @@ class TestReply:
 
     def test_reply_none(self):
         reply = controller.Reply(45)
-        reply.handle()
         reply.send(None)
         reply.take()
         reply.commit()
@@ -128,7 +66,6 @@ class TestReply:
 
     def test_commit_no_reply(self):
         reply = controller.Reply(46)
-        reply.handle()
         reply.take()
         with pytest.raises(ControlException):
             reply.commit()
@@ -137,7 +74,6 @@ class TestReply:
 
     def test_double_send(self):
         reply = controller.Reply(47)
-        reply.handle()
         reply.send(1)
         with pytest.raises(ControlException):
             reply.send(2)
@@ -145,12 +81,11 @@ class TestReply:
         reply.commit()
 
     def test_state_transitions(self):
-        states = {"unhandled", "handled", "taken", "committed"}
+        states = {"start", "taken", "committed"}
         accept = {
-            "handle": {"unhandled"},
-            "take": {"handled"},
+            "take": {"start"},
             "commit": {"taken"},
-            "ack": {"handled", "taken"},
+            "ack": {"start", "taken"},
         }
         for fn, ok in accept.items():
             for state in states:
@@ -169,7 +104,6 @@ class TestReply:
         reply = controller.Reply(47)
         with pytest.raises(ControlException):
             reply.__del__()
-        reply.handle()
         reply.ack()
         reply.take()
         reply.commit()
@@ -179,24 +113,24 @@ class TestDummyReply:
     def test_simple(self):
         reply = controller.DummyReply()
         for _ in range(2):
-            reply.handle()
             reply.ack()
             reply.take()
             reply.commit()
             reply.mark_reset()
             reply.reset()
-        assert reply.state == "unhandled"
+        assert reply.state == "start"
 
     def test_reset(self):
         reply = controller.DummyReply()
-        reply.handle()
         reply.ack()
         reply.take()
+        with pytest.raises(ControlException):
+            reply.mark_reset()
         reply.commit()
         reply.mark_reset()
         assert reply.state == "committed"
         reply.reset()
-        assert reply.state == "unhandled"
+        assert reply.state == "start"
 
     def test_del(self):
         reply = controller.DummyReply()
