@@ -2,42 +2,45 @@ import os.path
 import threading
 import tempfile
 import sys
+import time
+from unittest import mock
+import asyncio
 
 import mitmproxy.platform
+from mitmproxy.addons import core
 from mitmproxy.proxy.config import ProxyConfig
 from mitmproxy.proxy.server import ProxyServer
-from mitmproxy import master
 from mitmproxy import controller
 from mitmproxy import options
 from mitmproxy import exceptions
 from mitmproxy import io
-from mitmproxy import http
+from mitmproxy.utils import human
 import pathod.test
 import pathod.pathoc
 
+from mitmproxy import eventsequence
 from mitmproxy.test import tflow
 from mitmproxy.test import tutils
+from mitmproxy.test import taddons
 
 
 class MasterTest:
 
-    def cycle(self, master, content):
+    async def cycle(self, master, content):
         f = tflow.tflow(req=tutils.treq(content=content))
-        master.clientconnect(f.client_conn)
-        master.serverconnect(f.server_conn)
-        master.request(f)
-        if not f.error:
-            f.response = http.HTTPResponse.wrap(
-                tutils.tresp(content=content)
-            )
-            master.response(f)
-        master.clientdisconnect(f)
+        layer = mock.Mock("mitmproxy.proxy.protocol.base.Layer")
+        layer.client_conn = f.client_conn
+        layer.reply = controller.DummyReply()
+        await master.addons.handle_lifecycle("clientconnect", layer)
+        for i in eventsequence.iterate(f):
+            await master.addons.handle_lifecycle(*i)
+        await master.addons.handle_lifecycle("clientdisconnect", layer)
         return f
 
-    def dummy_cycle(self, master, n, content):
+    async def dummy_cycle(self, master, n, content):
         for i in range(n):
-            self.cycle(master, content)
-        master.shutdown()
+            await self.cycle(master, content)
+        await master._shutdown()
 
     def flowfile(self, path):
         with open(path, "wb") as f:
@@ -62,60 +65,66 @@ class TestState:
         if f not in self.flows:
             self.flows.append(f)
 
-    # TODO: add TCP support?
-    # def tcp_start(self, f):
-    #     if f not in self.flows:
-    #         self.flows.append(f)
 
+class TestMaster(taddons.RecordingMaster):
 
-class TestMaster(master.Master):
-
-    def __init__(self, opts, config):
-        s = ProxyServer(config)
-        master.Master.__init__(self, opts, s)
+    def __init__(self, opts):
+        super().__init__(opts)
+        config = ProxyConfig(opts)
+        self.server = ProxyServer(config)
 
     def clear_addons(self, addons):
         self.addons.clear()
         self.state = TestState()
         self.addons.add(self.state)
         self.addons.add(*addons)
-
-    def clear_log(self):
-        self.tlog = []
+        self.addons.trigger("configure", self.options.keys())
+        self.addons.trigger("running")
 
     def reset(self, addons):
         self.clear_addons(addons)
-        self.clear_log()
-
-    @controller.handler
-    def log(self, e):
-        self.tlog.append(e.msg)
+        self.clear()
 
 
 class ProxyThread(threading.Thread):
 
-    def __init__(self, tmaster):
+    def __init__(self, masterclass, options):
         threading.Thread.__init__(self)
-        self.tmaster = tmaster
-        self.name = "ProxyThread (%s:%s)" % (
-            tmaster.server.address.host, tmaster.server.address.port
-        )
+        self.masterclass = masterclass
+        self.options = options
+        self.tmaster = None
+        self.event_loop = None
         controller.should_exit = False
 
     @property
     def port(self):
-        return self.tmaster.server.address.port
+        return self.tmaster.server.address[1]
 
     @property
     def tlog(self):
-        return self.tmaster.tlog
-
-    def run(self):
-        self.tmaster.run()
+        return self.tmaster.logs
 
     def shutdown(self):
         self.tmaster.shutdown()
 
+    def run(self):
+        self.event_loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(self.event_loop)
+        self.tmaster = self.masterclass(self.options)
+        self.tmaster.addons.add(core.Core())
+        self.name = "ProxyThread (%s)" % human.format_address(self.tmaster.server.address)
+        self.tmaster.run()
+
+    def set_addons(self, *addons):
+        self.tmaster.reset(addons)
+
+    def start(self):
+        super().start()
+        while True:
+            if self.tmaster:
+                break
+            time.sleep(0.01)
+
 
 class ProxyTestBase:
     # Test Configuration
@@ -134,17 +143,15 @@ class ProxyTestBase:
             ssl=cls.ssl,
             ssloptions=cls.ssloptions)
 
-        opts = cls.get_options()
-        cls.config = ProxyConfig(opts)
-        tmaster = cls.masterclass(opts, cls.config)
-        cls.proxy = ProxyThread(tmaster)
+        cls.options = cls.get_options()
+        cls.proxy = ProxyThread(cls.masterclass, cls.options)
         cls.proxy.start()
 
     @classmethod
     def teardown_class(cls):
-        # perf: we want to run tests in parallell
+        # perf: we want to run tests in parallel
         # should this ever cause an error, travis should catch it.
-        # shutil.rmtree(cls.cadir)
+        # shutil.rmtree(cls.confdir)
         cls.proxy.shutdown()
         cls.server.shutdown()
         cls.server2.shutdown()
@@ -168,14 +175,17 @@ class ProxyTestBase:
 
     @classmethod
     def get_options(cls):
-        cls.cadir = os.path.join(tempfile.gettempdir(), "mitmproxy")
+        cls.confdir = os.path.join(tempfile.gettempdir(), "mitmproxy")
         return options.Options(
             listen_port=0,
-            cadir=cls.cadir,
+            confdir=cls.confdir,
             add_upstream_certs_to_client_chain=cls.add_upstream_certs_to_client_chain,
             ssl_insecure=True,
         )
 
+    def set_addons(self, *addons):
+        self.proxy.set_addons(*addons)
+
     def addons(self):
         """
             Can be over-ridden to add a standard set of addons to tests.
@@ -227,12 +237,12 @@ class HTTPProxyTest(ProxyTestBase):
             p = pathod.pathoc.Pathoc(
                 ("127.0.0.1", self.proxy.port), True, fp=None
             )
-            with p.connect((options.APP_HOST, options.APP_PORT)):
+            with p.connect((self.master.options.onboarding_host, self.master.options.onbarding_port)):
                 return p.request("get:'%s'" % page)
         else:
             p = self.pathoc()
             with p.connect():
-                return p.request("get:'http://%s%s'" % (options.APP_HOST, page))
+                return p.request("get:'http://%s%s'" % (self.master.options.onboarding_host, page))
 
 
 class TransparentProxyTest(ProxyTestBase):
@@ -287,7 +297,7 @@ class ReverseProxyTest(ProxyTestBase):
     @classmethod
     def get_options(cls):
         opts = ProxyTestBase.get_options()
-        opts.upstream_server = "".join(
+        s = "".join(
             [
                 "https" if cls.ssl else "http",
                 "://",
@@ -295,7 +305,7 @@ class ReverseProxyTest(ProxyTestBase):
                 str(cls.server.port)
             ]
         )
-        opts.mode = "reverse"
+        opts.mode = "reverse:" + s
         return opts
 
     def pathoc(self, sni=None):
@@ -330,8 +340,7 @@ class SocksModeTest(HTTPProxyTest):
         return opts
 
 
-class ChainProxyTest(ProxyTestBase):
-
+class HTTPUpstreamProxyTest(HTTPProxyTest):
     """
     Chain three instances of mitmproxy in a row to test upstream mode.
     Proxy order is cls.proxy -> cls.chain[0] -> cls.chain[1]
@@ -343,19 +352,18 @@ class ChainProxyTest(ProxyTestBase):
 
     @classmethod
     def setup_class(cls):
+        # We need to initialize the chain first so that the normal server gets a correct config.
         cls.chain = []
-        super().setup_class()
         for _ in range(cls.n):
             opts = cls.get_options()
-            config = ProxyConfig(opts)
-            tmaster = cls.masterclass(opts, config)
-            proxy = ProxyThread(tmaster)
+            proxy = ProxyThread(cls.masterclass, opts)
             proxy.start()
             cls.chain.insert(0, proxy)
+            while True:
+                if proxy.event_loop and proxy.event_loop.is_running():
+                    break
 
-        # Patch the orginal proxy to upstream mode
-        opts = cls.get_options()
-        cls.config = cls.proxy.tmaster.config = cls.proxy.tmaster.server.config = ProxyConfig(opts)
+        super().setup_class()
 
     @classmethod
     def teardown_class(cls):
@@ -372,12 +380,8 @@ class ChainProxyTest(ProxyTestBase):
     def get_options(cls):
         opts = super().get_options()
         if cls.chain:  # First proxy is in normal mode.
+            s = "http://127.0.0.1:%s" % cls.chain[0].port
             opts.update(
-                mode="upstream",
-                upstream_server="http://127.0.0.1:%s" % cls.chain[0].port
+                mode="upstream:" + s,
             )
         return opts
-
-
-class HTTPUpstreamProxyTest(ChainProxyTest, HTTPProxyTest):
-    pass
