@@ -1,5 +1,4 @@
 import io
-import subprocess
 import sys
 from unittest import mock
 import pytest
@@ -11,13 +10,7 @@ from mitmproxy.utils import debug
 def test_dump_system_info_precompiled(precompiled):
     sys.frozen = None
     with mock.patch.object(sys, 'frozen', precompiled):
-        assert ("Precompiled Binary" in debug.dump_system_info()) == precompiled
-
-
-def test_dump_system_info_version():
-    with mock.patch('subprocess.check_output') as m:
-        m.side_effect = subprocess.CalledProcessError(-1, 'git describe --tags --long')
-        assert 'release version' in debug.dump_system_info()
+        assert ("binary" in debug.dump_system_info()) == precompiled
 
 
 def test_dump_info():
