@@ -1,5 +1,6 @@
+import React from 'react'
 import { MessageUtils } from "../../flow/utils"
-import { PropTypes } from 'react'
+import PropTypes from 'prop-types'
 
 DownloadContentButton.propTypes = {
     flow: PropTypes.object.isRequired,
