@@ -1,14 +1,16 @@
 import React from 'react'
+import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
 import { formatSize } from '../utils.js'
+import HideInStatic from '../components/common/HideInStatic'
 
 Footer.propTypes = {
-    settings: React.PropTypes.object.isRequired,
+    settings: PropTypes.object.isRequired,
 }
 
 function Footer({ settings }) {
     let {mode, intercept, showhost, no_upstream_cert, rawtcp, http2, websocket, anticache, anticomp,
-            stickyauth, stickycookie, stream_large_bodies, listen_host, listen_port, version} = settings;
+            stickyauth, stickycookie, stream_large_bodies, listen_host, listen_port, version, server} = settings;
     return (
         <footer>
             {mode && mode != "regular" && (
@@ -48,9 +50,14 @@ function Footer({ settings }) {
                 <span className="label label-success">stream: {formatSize(stream_large_bodies)}</span>
             )}
             <div className="pull-right">
-            <span className="label label-primary" title="HTTP Proxy Server Address">
-            {listen_host || "*"}:{listen_port}
-            </span>
+                <HideInStatic>
+                {
+                    server && (
+                    <span className="label label-primary" title="HTTP Proxy Server Address">
+                        {listen_host||"*"}:{listen_port}
+                    </span>)
+                }
+                </HideInStatic>
             <span className="label label-info" title="Mitmproxy Version">
             v{version}
             </span>
