@@ -1,4 +1,5 @@
-import { PropTypes } from 'react'
+import React from "react"
+import PropTypes from "prop-types"
 
 DocsLink.propTypes = {
     resource: PropTypes.string.isRequired,
